#
# spec file for package OpenImageDenoise
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2019-2021 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1
%define libname lib%{name}%{sover}
%define pkgname oidn
Name:           OpenImageDenoise
Version:        1.4.3
Release:        1.8
Summary:        Open Image Denoise library
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://openimagedenoise.github.io/
Source:         https://github.com/%{name}/%{pkgname}/releases/download/v%{version}/%{pkgname}-%{version}.src.tar.gz
BuildRequires:  cmake >= 3.1
BuildRequires:  gcc-c++
BuildRequires:  ispc
BuildRequires:  tbb-devel
ExclusiveArch:  x86_64

%description
Intel Open Image Denoise is an open source library of high-performance,
high-quality denoising filters for images rendered with ray tracing.

%package -n %{libname}
Summary:        Open Image Denoise library
Group:          System/Libraries

%description -n %{libname}
Intel Open Image Denoise is an open source library of high-performance,
high-quality denoising filters for images rendered with ray tracing.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description	devel
This package contains the C++ header files and symbolic links to the shared
libraries for %{name}. If you would like to develop programs using %{name},
you will need to install %{name}-devel.

%prep
%setup -q -n %{pkgname}-%{version}
sed -i 's|-${OIDN_VERSION}$||' cmake/oidn_install.cmake

%build
%cmake
make %{?_smp_mflags}

%install
%cmake_install
rm -r %{buildroot}%{_datadir}/doc

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%license LICENSE.txt
%{_bindir}/oidn*

%files -n %{libname}
%license LICENSE.txt
%{_libdir}/lib%{name}.so.*

%files devel
%license LICENSE.txt
%doc CHANGELOG.md README.md readme.pdf
%{_includedir}/%{name}
%{_libdir}/cmake/%{name}
%{_libdir}/lib%{name}.so

%changelog
* Fri Apr 22 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.4.3:
  + Disabled VTune profiling support of oneDNN kernels
- Update to 1.4.2:
  + Added support for 16-bit half-precision floating-point images
  + Added oidnGetBufferData and oidnGetBufferSize functions
  + Fixed performance issue on x86 hybrid architecture CPUs
  + Fixed build error when using OpenImageIO 2.3 or later
* Sun Sep 26 2021 Hans-Peter Jansen <hpj@urpla.net>
- Update to 1.4.1:
  + Fixed crash when in-place denoising images with certain unusual
    resolutions
  + Fixed compile error when building for Apple Silicon using some
    unofficial builds of ISPC
- Update to 1.4.0:
  + Improved fine detail preservation
  + Added the cleanAux filter parameter for further improving
    quality when the auxiliary feature (albedo, normal) images are
    noise-free
  + Added support for denoising auxiliary feature images, which can
    be used together with the new cleanAux parameter for improving
    quality when the auxiliary images are noisy (recommended for
    final frame denoising)
  + Normals are expected to be in the [-1, 1] range (but still do
    not have to be normalized)
  + Added the oidnUpdateFilterData function which must be called
    when the contents of an opaque data parameter bound to a filter
    (e.g. weights) has been changed after committing the filter
  + Added the oidnRemoveFilterImage and oidnRemoveFilterData
    functions for removing previously set image and opaque data
    parameters of filters
  + Reduced the overhead of oidnCommitFilter to zero in some cases
    (e.g. when changing already set image buffers/pointers or the
    inputScale parameter)
  + Reduced filter memory consumption by about 35%%
  + Reduced total memory consumption significantly when using
    multiple filters that belong to the same device
  + Reduced the default maximum memory consumption to 3000 MB
  + Added the OIDN_FILTER_RT and OIDN_FILTER_RTLIGHTMAP CMake
    options for excluding the trained filter weights from the build
    to significantly decrease its size
  + Fixed detection of static TBB builds on Windows
  + Fixed compile error when using future glibc versions
  + Added oidnBenchmark option for setting custom resolutions
  + Upgraded to oneTBB 2021.2.0 in the official binaries
- Update to 1.3.0:
  + Improved denoising quality
  + Improved sharpness of fine details / less blurriness
  + Fewer noisy artifacts
  + Slightly improved performance and lowered memory consumption
  + Added directional (e.g. spherical harmonics) lightmap denoising
    to the RTLightmap filter
  + Added inputScale filter parameter which generalizes the
    existing (and thus now deprecated) hdrScale parameter for non-
    HDR images
  + Added native support for Apple Silicon and the BNNS library on
    macOS (currently requires rebuilding from source)
  + Added OIDN_NEURAL_RUNTIME CMake option for setting the neural
    network runtime library
  + Reduced the size of the library binary
  + Fixed compile error on some older macOS versions
  + Upgraded release builds to use oneTBB 2021.1.1
  + Removed tbbmalloc dependency
  + Appended the library version to the name of the directory
    containing the installed CMake files
  + Training:
  + Faster training performance
  + Added mixed precision training (enabled by default)
  + Added efficient data-parallel training on multiple GPUs
  + Enabled preprocessing datasets multiple times with possibly
    different options
  + Minor bugfixes
- Update to 1.2.4:
  + Added OIDN_API_NAMESPACE CMake option that allows to put all
    API functions inside a user-defined namespace
  + Fixed bug when TBB_USE_GLIBCXX_VERSION is defined
  + Fixed compile error when using an old compiler which does not
    support OpenMP SIMD
  + Added compatibility with oneTBB 2021
  + Export only necessary symbols on Linux and macOS
- Update to 1.2.3:
  + Fixed incorrect detection of AVX-512 on macOS (sometimes
    causing a crash)
  + Fixed inconsistent performance and costly initialization for
    AVX-512
  + Fixed JIT'ed AVX-512 kernels not showing up correctly in VTune
- Eliminate version from installed cmake directory
* Fri Aug 28 2020 Dirk Mueller <dmueller@suse.com>
- Update to 1.2.2:
  * Fixed unhandled exception when canceling filter execution from the
    progress monitor callback function
  * Fixed tiling artifacts when in-place denoising (using one of the input
  * Fixed ghosting/color bleeding artifacts in black regions when using
  * Fixed error when building as a static library (`OIDN_STATIC_LIB` option)
  * Fixed compile error for ISPC 1.13 and later
  * Fixed minor TBB detection issues
  * Fixed crash on pre-SSE4 CPUs when using some recent compilers (e.g. GCC 10)
  * Link C/C++ runtime library dynamically on Windows too by default
  * Renamed example apps (`oidnDenoise`, `oidnTest`)
  * Added benchmark app (`oidnBenchmark`)
  * Fixed random data augmentation seeding in training
  * Fixed training warning with PyTorch 1.5 and later
  * Added neural network training code
  * Added support for specifying user-trained models at runtime
  * Slightly improved denoising quality
  * Improved denoising speed by about 7-38%% (mostly depending on the compiler)
  * Added `OIDN_STATIC_RUNTIME` CMake option (for Windows only)
  * Added support for OpenImageIO to the example apps (disabled by default)
  * Added check for minimum supported TBB version
  * Find debug versions of TBB
  * Added testing
* Thu Jan 16 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Build only for x86_64 as it is the only supported platform
* Tue Dec 10 2019 Hans-Peter Jansen <hpj@urpla.net>
- Add memory contraints: 8G
* Wed Nov 20 2019 Hans-Peter Jansen <hpj@urpla.net>
- Version 1.1.0: initial build
